@@ -6,9 +6,9 @@ showdatetime<-function(rd, AMPM=FALSE)
 
   MODAY = getmoday(rd$jd,  rd$yr)
 
-  gdates = paste(sep="-", formatC(rd$yr, wid=3 , flag = "0") ,
-    formatC( MODAY$mo , wid=2 , flag = "0"),
-    formatC( MODAY$dom , wid=2 , flag = "0"))
+  gdates = paste(sep="-", formatC(rd$yr, width=3 , flag = "0") ,
+    formatC( MODAY$mo , width=2 , flag = "0"),
+    formatC( MODAY$dom , width=2 , flag = "0"))
 
   mysec = floor(rd$sec)
   mymcrsec = floor((rd$sec-mysec)*1000000)
@@ -23,11 +23,11 @@ showdatetime<-function(rd, AMPM=FALSE)
     }
   
   gtimes = paste(sep=":",
-    formatC(hours, wid=2 , flag = "0"),
-    formatC(rd$mi, wid=2 , flag = "0"),
-    formatC(mysec, wid=2 , flag = "0") )
+    formatC(hours, width=2 , flag = "0"),
+    formatC(rd$mi, width=2 , flag = "0"),
+    formatC(mysec, width=2 , flag = "0") )
 
-  amcrsec =  formatC(as.integer(mymcrsec), wid=6, flag = "0")
+  amcrsec =  formatC(as.integer(mymcrsec), width=6, flag = "0")
 
  
 
